@@ -1,17 +1,21 @@
-from pydantic import BaseModel
 from enum import Enum
-from typing import List, Tuple, Optional
+from typing import List, Optional, Tuple
+
+from pydantic import BaseModel
 
 # Algorithms
 
+
 class AlgorithmName(str, Enum):
     winnowing = "winnowing"
 
+
 class AlgorithmRestModel(BaseModel):
     algorithm_name: AlgorithmName
 
 # Checks
 
+
 class OptionsRestModel(BaseModel):
     sensitivity: float
 
@@ -39,4 +43,3 @@ class CheckResultRestModel(BaseModel):
 class CheckRestModel(BaseModel):
     name: str
     matches: List[CheckResultRestModel]
-
