@@ -1,8 +1,10 @@
-from pydantic import BaseModel
 from typing import List, Tuple
 
+from pydantic import BaseModel
+
 # Files
 
+
 class CreateFileRestModel(BaseModel):
     name: str
     extension: str
@@ -18,11 +20,12 @@ class MutipleFilesRestModel(BaseModel):
 
 # Checks
 
+
 class FileResultRestModel(BaseModel):
     id: str
     name: str
     match_percentage: float
-    lines_matched: List[Tuple[int, int]]
+    lines_matched: List[Tuple[str, int, int]]
 
 
 class CheckMatchRestModel(BaseModel):
@@ -37,4 +40,4 @@ class CreateCheckRestModel(BaseModel):
 
 class MultipleCheckRestModel(BaseModel):
     id: str
-    name: str
\ No newline at end of file
+    name: str
